@@ -1098,28 +1098,40 @@ def create_edit_person_time_sheet(request, person_id=None):
 
 @permission_required('timepiece.view_payroll_summary')
 @render_with('timepiece/time-sheet/reports/summary.html')
-@utils.date_filter
-def payroll_summary(request, form, from_date, to_date, status, activity):
+def payroll_summary(request):
+    year_month_form = timepiece_forms.YearMonthForm(request.GET or None)
+    if request.GET and year_month_form.is_valid():
+        from_date, to_date = year_month_form.save()
+    else:
+        from_date = utils.get_month_start(datetime.datetime.today()).date()
+        to_date = from_date + relativedelta(months=1)
     last_billable = utils.get_last_billable_day(from_date)
-    all_weeks = utils.generate_dates(start=from_date,
-                                     end=last_billable, by='week')
-    workers = timepiece.Entry.objects.filter(
-        end_time__gt=utils.get_week_start(from_date),
-        end_time__lt=last_billable + datetime.timedelta(days=1)
-        ).values_list('user', flat=True).distinct()
-    rps = timepiece.PersonRepeatPeriod.objects.select_related(
-        'user', 'repeat_period',
-    ).filter(
-        repeat_period__active=True, user__id__in=workers
-    ).order_by('user__last_name')
-    for rp in rps:
-        rp.user.summary = rp.summary(from_date, to_date)
+    projects = getattr(settings, 'TIMEPIECE_PROJECTS', {})
+    workQ = ~Q(project__in=projects.values())
+    weekQ = Q(end_time__gt=utils.get_week_start(from_date),
+              end_time__lt=last_billable + datetime.timedelta(days=1))
+    monthQ = Q(end_time__gt=from_date, end_time__lt=to_date)
+    statusQ = Q(status='invoiced') | Q(status='approved')
+    weekQ &= statusQ
+    monthQ &= statusQ
+    #Weekly totals
+    entries = timepiece.Entry.objects.date_trunc('week').filter(weekQ, workQ)
+    date_headers = utils.generate_dates(from_date, last_billable, by='week')
+    weekly_totals = list(utils.project_totals(entries, date_headers, 'total',
+                                              overtime=True))
+    #Monthly totals
+    leave = timepiece.Entry.objects.filter(monthQ, ~workQ
+                                  ).values('user', 'hours', 'project__name')
+    month_entries = timepiece.Entry.objects.date_trunc('month').filter(monthQ,
+                                                                       workQ)
+    monthly_totals = list(utils.payroll_totals(month_entries, from_date,
+                                               leave))
     return {
-        'form': form,
-        'all_weeks': all_weeks,
-        'periods': rps,
-        'to_date': to_date,
         'from_date': from_date,
+        'year_month_form': year_month_form,
+        'date_headers': date_headers,
+        'weekly_totals': weekly_totals,
+        'monthly_totals': monthly_totals,
     }
 
 
@@ -1224,8 +1236,12 @@ def hourly_report(request, date_form, from_date, to_date, status, activity):
         headers = ['Name']
         headers.extend([date.strftime('%m/%d/%Y') for date in date_headers])
         writer.writerow(headers)
-        for name, hours in project_totals:
-            data = [' '.join((name[1], name[0]))]
-            data.extend([hour or '' for hour in hours])
-            writer.writerow(data)
+        for rows, totals in project_totals:
+            for name, hours in rows:
+                data = [name]
+                data.extend(hours)
+                writer.writerow(data)
+            total = ['Totals']
+            total.extend(totals)
+            writer.writerow(total)
         return response
